@@ -1,8 +1,8 @@
-#!/bin/sh
+#!/sbin/sh
 ####################################################################################
 ## FILENAME:    OA-setup.sh
-## VERSION:     08.60.020
-## DESCRIPTION: HPUX/Solaris OMU8 server side  installation script for OpenVMS
+## VERSION:     08.60.030
+## DESCRIPTION: HPUX OMU8 server side  installation script for OpenVMS
 ##              Operation Agent
 ##              Script can be used for 
 ##              1. Pre-requisite check for server version, Disk Space for 
@@ -201,21 +201,11 @@ get_HTTPS_version()
 get_free_ds()
 {
 
-   case `uname -s` in
-   HP-UX)
-       df $1 \
-          | awk 'BEGIN {s=0} { if ($3 != "):" ) {s=$3 / 2} else {s=$4 / 2} } \
-                 END {printf "%d\n", s}'
-       ;;
-   SunOS)
-       df -k $1 \
-             | /usr/bin/awk 'BEGIN { s = 0 } NF > 1 && NF < 6 { s = $3 } \
-                             NF == 6 { s = $4 } END { printf "%d\n", s }'
-       ;;
-   *)
-       return 0
-       ;;
-   esac
+   df $1 \
+      | awk 'BEGIN {s=0} { if ($3 != "):" ) {s=$3 / 2} else {s=$4 / 2} } \
+             END {printf "%d\n", s}'
+
+
 }
 #------------------------------------------------------------------------------
 display_details()
@@ -627,18 +617,7 @@ del_vms()
 #------------------------------------------------------------------------------
 copy_srv_script()
 {
-   case `uname -s` in
-   HP-UX)
-      SRC_DIR="OMU8-HPUX"
-      ;;
-   SunOS)
-      SRC_DIR="OMU8-SOL"
-      ;;
-       *)
-         Log_msg "Unsupported OS."
-         return 1
-      ;;
-   esac
+   SRC_DIR="OMU8-HPUX" 
 
    SRC_DIR1=`echo $DIRNAME/ServerScripts/$SRC_DIR`
 
@@ -706,18 +685,7 @@ reg_comp()
 #------------------------------------------------------------------------------
 copy_vms_kits()
 {
-   case `uname -s` in
-   HP-UX)
-      SRC_DIR="OMU8-HPUX"
-      ;;
-   SunOS)
-      SRC_DIR="OMU8-SOL"
-      ;;
-       *)
-         Log_msg "Unsupported OS."
-         return 1
-      ;;
-   esac
+   SRC_DIR="OMU8-HPUX"
    
   if [ $ALPHA_SELECT -eq 1 ]
   then
@@ -960,7 +928,7 @@ echo "  -verbose|vv   Verbose output."
 echo ""
 echo "NOTE: you must be root to run this script."
 
-  Log_msg "          OVO Maintenance script ends `date`."
+  Log_msg "          OM OpenVMS 8.6 OA Maintenance script ends `date`."
 }
 #------------------------------------------------------------------------------
 
@@ -973,34 +941,20 @@ then
 fi
 touch ${INST_LOG_FILE}
 
-Log_msg "          OMU OpenVMS 8.6 OA Maintenance script starts `date`."
+Log_msg "          OM OpenVMS 8.6 OA Maintenance script starts `date`."
 check_lockfile
 if [ $? -ne 0 ]
 then
-  Log_msg "          OMU OpenVMS 8.6 Maintenance script is already running - exiting `date`."
+  Log_msg "          OM OpenVMS 8.6 OA Maintenance script is already running - exiting `date`."
   return 1
 fi
-case `uname -s` in
-   HP-UX)
-     om_vms_chk_usr "root"
-     if [ $? -ne 0 ]
-     then
-       print_usage
-       remove_lockfile
-       return 1
-     fi
-     ;;
-   SunOS)
-      `who am i | grep root > /dev/null`
-       if [ $? -ne 0 ]
-       then
-         Log_msg "User must be root."
-         print_usage
-         remove_lockfile
-         return 1
-       fi
-       ;;
-esac
+om_vms_chk_usr "root"
+if [ $? -ne 0 ]
+then
+    print_usage
+    remove_lockfile
+    return 1
+fi
 
 if [ $# -eq 0 ]
 then
@@ -1096,4 +1050,4 @@ then
    verify_after
 fi
 remove_lockfile
-Log_msg " OVO Maintenance script ends `date`."
+Log_msg " OM OpenVMS 8.6 OA Maintenance script ends `date`."
